"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearAll = exports.clearExpired = exports.get = void 0;
const store_1 = require("svelte/store");
const getCached = (key) => {
    const cached = localStorage.getItem(key);
    if (cached) {
        return JSON.parse(cached);
    }
};
const setCached = (key, data) => {
    localStorage.setItem(key, JSON.stringify(data));
};
const generateKey = (requestInfo) => {
    if (typeof requestInfo === "string") {
        return `ssf[${requestInfo}]`;
    }
    let headers = [];
    for (const [key, value] of requestInfo.headers) {
        headers.push(`${key}:${value}`);
    }
    return `ssf[${requestInfo.method} ${requestInfo.url} ${hashCode(`${headers}`)}]`;
};
const hashCode = (s) => {
    var hash = 0, i, chr;
    for (i = 0; i < s.length; i++) {
        chr = s.charCodeAt(i);
        hash = ((hash << 5) - hash) + chr;
        hash |= 0;
    }
    return hash.toString(16);
};
const get = (requestInfo, cacheMs = 10) => {
    const store = store_1.writable(new Promise(() => { }));
    const now = new Date().getTime();
    const key = generateKey(requestInfo);
    const cached = getCached(key);
    if (cached) {
        store.set(Promise.resolve(cached.data));
        if (cached.until > now) {
            return store;
        }
    }
    (async () => {
        const response = await fetch(requestInfo);
        const data = await response.json();
        store.set(Promise.resolve(data));
        setCached(key, { until: now + cacheMs, data: data });
    })();
    return store;
};
exports.get = get;
const clearExpired = () => {
    for (let i = 0; i < localStorage.length; i++) {
        const key = localStorage.key(i);
        if (!key || !key.startsWith("ssf[") || !key.endsWith("]")) {
            continue;
        }
        const cached = getCached(key);
        if (cached && cached.until > new Date().getTime()) {
            localStorage.removeItem(key);
        }
    }
};
exports.clearExpired = clearExpired;
const clearAll = () => {
    for (let i = 0; i < localStorage.length; i++) {
        const key = localStorage.key(i);
        if (key?.startsWith("ssf[") && key?.endsWith("]")) {
            localStorage.removeItem(key);
        }
    }
};
exports.clearAll = clearAll;
